pub struct BlockGeometryDirectionalDerivative {
pub d_design: Option<Array2<f64>>,
pub d_offset: Array1<f64>,
}Fields
d_design: Option<Array2<f64>>Directional derivative of the block design matrix along a coefficient-space direction.
d_offset: Array1<f64>Directional derivative of the block offset along the same direction.