checked_exp_log_strength

Function checked_exp_log_strength 

pub fn checked_exp_log_strength(
    log_strength: f64,
) -> Result<f64, LogStrengthDomainError>
Exponentiate a logarithmic strength on the exact closed solver domain.

No input is clamped and no output is floored or capped. Thus the returned value is exactly the one whose first and second rho derivatives are both exp(rho).