pub fn checked_log_strength(
strength: f64,
) -> Result<f64, PhysicalStrengthDomainError>Expand description
Recover a canonical logarithmic coordinate without flooring or ceilinging a physical strength.
pub fn checked_log_strength(
strength: f64,
) -> Result<f64, PhysicalStrengthDomainError>Recover a canonical logarithmic coordinate without flooring or ceilinging a physical strength.