pub struct SeedConfig {
pub bounds: (f64, f64),
pub max_seeds: usize,
pub seed_budget: usize,
pub screen_max_inner_iterations: usize,
pub risk_profile: SeedRiskProfile,
pub num_auxiliary_trailing: usize,
pub over_smoothing_probe_rho: Option<f64>,
}Fields
bounds: (f64, f64)max_seeds: usizeseed_budget: usizeMaximum number of seed starts to run in heuristic order.
screen_max_inner_iterations: usizeInitial inner-iteration cap used while ranking candidate seeds.
risk_profile: SeedRiskProfilenum_auxiliary_trailing: usizeNumber of trailing dimensions that are auxiliary parameters rather than log-smoothing parameters.
over_smoothing_probe_rho: Option<f64>Optional absolute over-smoothing probe on every smoothing dimension.