pub fn in_nested_parallel_region() -> bool
true when the current thread is inside at least one [NestedParallelGuard] scope, i.e. a parallel row reduction is already in flight on this thread.
true
NestedParallelGuard